==> tiki-9.7.tar.bz2: tiki-9.7/modules/mod-func-top_visited_blogs.php <==
<?php
// (c) Copyright 2002-2012 by authors of the Tiki Wiki CMS Groupware Project
//
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: mod-func-top_visited_blogs.php 40388 2012-03-26 04:05:54Z lindonb $

//this script may only be included - so its better to die if called directly.
if (strpos($_SERVER["SCRIPT_NAME"], basename(__FILE__)) !== false) {
  header("location: index.php");
  exit;
}

function module_top_visited_blogs_info()
{
	return array(
		'name' => tra('Top Visited Blogs'),
		'description' => tra('Display the specified number of blogs with links to them, from the most visited one to the least.'),
		'prefs' => array('feature_blogs'),
		'params' => array(
			'showlastpost' => array(
				'name' => tra('Show Last Post'),
				'description' => 'y|n',
				'required' => false,
				'filter' => 'alpha'
			),
			'sort_mode' => array(
				'name' => tra('Sort Mode'),
				'description' => tra('Sort Mode'),
				'required' => false,
				'filter' => 'word'
			),
		),
		'common_params' => array('nonums', 'rows')
	);
}

function module_top_visited_blogs($mod_reference, $module_params)
{
	global $smarty;
	global $bloglib; require_once('lib/blogs/bloglib.php');
	$with = '';
	if (isset($mod_reference['params']['showlastpost']) && $mod_reference['params']['showlastpost'] == 'y') {
		$with = array('showlastpost'=>'y');
	}
	if (empty($mod_reference['sort_mode'])) {
		$mod_reference['sort_mode'] = 'hits_desc';
	}
	$ranking = $bloglib->list_blogs(0, $mod_reference['rows'], $mod_reference['sort_mode'], '', 'blog', $with);
	
	$smarty->assign('modTopVisitedBlogs', $ranking['data']);
}

==> tiki-19.1.tar.bz2: tiki-19.1/modules/mod-func-top_visited_blogs.php <==
<?php
// (c) Copyright by authors of the Tiki Wiki CMS Groupware Project
//
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: mod-func-top_visited_blogs.php 66101 2018-04-19 18:03:14Z luciash $

//this script may only be included - so its better to die if called directly.
if (strpos($_SERVER["SCRIPT_NAME"], basename(__FILE__)) !== false) {
	header("location: index.php");
	exit;
}

/**
 * @return array
 */
function module_top_visited_blogs_info()
{
	return [
		'name' => tra('Top Visited Blogs'),
		'description' => tra('Display the specified number of blogs with links to them, from the most visited one to the least.'),
		'prefs' => ['feature_blogs'],
		'params' => [
			'showlastpost' => [
				'name' => tra('Show Last Post'),
				'description' => 'y|n',
				'required' => false,
				'filter' => 'alpha'
			],
			'sort_mode' => [
				'name' => tra('Sort Mode'),
				'description' => tra('Sort Mode'),
				'required' => false,
				'filter' => 'word'
			],
		],
		'common_params' => ['nonums', 'rows']
	];
}

/**
 * @param $mod_reference
 * @param $module_params
 */
function module_top_visited_blogs($mod_reference, $module_params)
{
	$smarty = TikiLib::lib('smarty');
	$bloglib = TikiLib::lib('blog');
	$with = '';
	if (isset($mod_reference['params']['showlastpost']) && $mod_reference['params']['showlastpost'] == 'y') {
		$with = ['showlastpost' => 'y'];
	}
	if (empty($mod_reference['sort_mode'])) {
		$mod_reference['sort_mode'] = 'hits_desc';
	}
	$ranking = $bloglib->list_blogs(0, $mod_reference['rows'], $mod_reference['sort_mode'], '', 'blog', $with);

	$smarty->assign('modTopVisitedBlogs', $ranking['data']);
}
